# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) Spyder Project Developers
#
# Licensed under the terms of the MIT License
# (see LICENSE.txt for details)
# -----------------------------------------------------------------------------
"""Spyder unitest plugin."""

# Local imports
from .unittestplugin import UnitTestPlugin as PLUGIN_CLASS

__version__ = '0.1.0'
PLUGIN_CLASS
